# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.folders import (
    V3ListResponse,
    V3CreateResponse,
    V3AddPapersResponse,
    V3MovePapersResponse,
    V3ToggleSharingResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV3:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create(self, client: AlphaxivCat) -> None:
        v3 = client.folders.v3.create(
            folder_name="x",
        )
        assert_matches_type(V3CreateResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: AlphaxivCat) -> None:
        response = client.folders.v3.with_raw_response.create(
            folder_name="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3CreateResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: AlphaxivCat) -> None:
        with client.folders.v3.with_streaming_response.create(
            folder_name="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3CreateResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list(self, client: AlphaxivCat) -> None:
        v3 = client.folders.v3.list()
        assert_matches_type(V3ListResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: AlphaxivCat) -> None:
        response = client.folders.v3.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3ListResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: AlphaxivCat) -> None:
        with client.folders.v3.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3ListResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete(self, client: AlphaxivCat) -> None:
        v3 = client.folders.v3.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete(self, client: AlphaxivCat) -> None:
        response = client.folders.v3.with_raw_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete(self, client: AlphaxivCat) -> None:
        with client.folders.v3.with_streaming_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_delete(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            client.folders.v3.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_add_papers(self, client: AlphaxivCat) -> None:
        v3 = client.folders.v3.add_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3AddPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_add_papers_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.folders.v3.add_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            universal_ids=["string"],
        )
        assert_matches_type(V3AddPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_add_papers(self, client: AlphaxivCat) -> None:
        response = client.folders.v3.with_raw_response.add_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3AddPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_add_papers(self, client: AlphaxivCat) -> None:
        with client.folders.v3.with_streaming_response.add_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3AddPapersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_add_papers(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            client.folders.v3.with_raw_response.add_papers(
                folder_id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_move_papers(self, client: AlphaxivCat) -> None:
        v3 = client.folders.v3.move_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        )
        assert_matches_type(V3MovePapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_move_papers_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.folders.v3.move_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            from_folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3MovePapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_move_papers(self, client: AlphaxivCat) -> None:
        response = client.folders.v3.with_raw_response.move_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3MovePapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_move_papers(self, client: AlphaxivCat) -> None:
        with client.folders.v3.with_streaming_response.move_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3MovePapersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_move_papers(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            client.folders.v3.with_raw_response.move_papers(
                folder_id="",
                paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_remove_papers(self, client: AlphaxivCat) -> None:
        v3 = client.folders.v3.remove_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_remove_papers(self, client: AlphaxivCat) -> None:
        response = client.folders.v3.with_raw_response.remove_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_remove_papers(self, client: AlphaxivCat) -> None:
        with client.folders.v3.with_streaming_response.remove_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_remove_papers(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            client.folders.v3.with_raw_response.remove_papers(
                folder_id="",
                paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_toggle_sharing(self, client: AlphaxivCat) -> None:
        v3 = client.folders.v3.toggle_sharing(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            sharing_status="not_shared",
        )
        assert_matches_type(V3ToggleSharingResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_toggle_sharing(self, client: AlphaxivCat) -> None:
        response = client.folders.v3.with_raw_response.toggle_sharing(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            sharing_status="not_shared",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3ToggleSharingResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_toggle_sharing(self, client: AlphaxivCat) -> None:
        with client.folders.v3.with_streaming_response.toggle_sharing(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            sharing_status="not_shared",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3ToggleSharingResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_toggle_sharing(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            client.folders.v3.with_raw_response.toggle_sharing(
                folder_id="",
                sharing_status="not_shared",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_name(self, client: AlphaxivCat) -> None:
        v3 = client.folders.v3.update_name(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            name="x",
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update_name(self, client: AlphaxivCat) -> None:
        response = client.folders.v3.with_raw_response.update_name(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            name="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update_name(self, client: AlphaxivCat) -> None:
        with client.folders.v3.with_streaming_response.update_name(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            name="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update_name(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            client.folders.v3.with_raw_response.update_name(
                folder_id="",
                name="x",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_parent(self, client: AlphaxivCat) -> None:
        v3 = client.folders.v3.update_parent(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update_parent(self, client: AlphaxivCat) -> None:
        response = client.folders.v3.with_raw_response.update_parent(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update_parent(self, client: AlphaxivCat) -> None:
        with client.folders.v3.with_streaming_response.update_parent(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update_parent(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            client.folders.v3.with_raw_response.update_parent(
                folder_id="",
                parent_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )


class TestAsyncV3:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.folders.v3.create(
            folder_name="x",
        )
        assert_matches_type(V3CreateResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.folders.v3.with_raw_response.create(
            folder_name="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3CreateResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.folders.v3.with_streaming_response.create(
            folder_name="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3CreateResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.folders.v3.list()
        assert_matches_type(V3ListResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.folders.v3.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3ListResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.folders.v3.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3ListResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.folders.v3.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.folders.v3.with_raw_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.folders.v3.with_streaming_response.delete(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            await async_client.folders.v3.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_add_papers(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.folders.v3.add_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3AddPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_add_papers_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.folders.v3.add_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            universal_ids=["string"],
        )
        assert_matches_type(V3AddPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_add_papers(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.folders.v3.with_raw_response.add_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3AddPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_add_papers(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.folders.v3.with_streaming_response.add_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3AddPapersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_add_papers(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            await async_client.folders.v3.with_raw_response.add_papers(
                folder_id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_move_papers(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.folders.v3.move_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        )
        assert_matches_type(V3MovePapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_move_papers_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.folders.v3.move_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            from_folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3MovePapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_move_papers(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.folders.v3.with_raw_response.move_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3MovePapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_move_papers(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.folders.v3.with_streaming_response.move_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3MovePapersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_move_papers(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            await async_client.folders.v3.with_raw_response.move_papers(
                folder_id="",
                paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_remove_papers(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.folders.v3.remove_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_remove_papers(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.folders.v3.with_raw_response.remove_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_remove_papers(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.folders.v3.with_streaming_response.remove_papers(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_remove_papers(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            await async_client.folders.v3.with_raw_response.remove_papers(
                folder_id="",
                paper_group_ids=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_toggle_sharing(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.folders.v3.toggle_sharing(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            sharing_status="not_shared",
        )
        assert_matches_type(V3ToggleSharingResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_toggle_sharing(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.folders.v3.with_raw_response.toggle_sharing(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            sharing_status="not_shared",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3ToggleSharingResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_toggle_sharing(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.folders.v3.with_streaming_response.toggle_sharing(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            sharing_status="not_shared",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3ToggleSharingResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_toggle_sharing(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            await async_client.folders.v3.with_raw_response.toggle_sharing(
                folder_id="",
                sharing_status="not_shared",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_name(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.folders.v3.update_name(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            name="x",
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update_name(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.folders.v3.with_raw_response.update_name(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            name="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update_name(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.folders.v3.with_streaming_response.update_name(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            name="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update_name(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            await async_client.folders.v3.with_raw_response.update_name(
                folder_id="",
                name="x",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_parent(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.folders.v3.update_parent(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update_parent(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.folders.v3.with_raw_response.update_parent(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update_parent(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.folders.v3.with_streaming_response.update_parent(
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update_parent(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `folder_id` but received ''"):
            await async_client.folders.v3.with_raw_response.update_parent(
                folder_id="",
                parent_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal, TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = [
    "V3GetActivityResponse",
    "V3GetActivityResponseItem",
    "V3GetActivityResponseItemItem",
    "V3GetActivityResponseItemItemAnnotation",
    "V3GetActivityResponseItemItemAnnotationAnchorPosition",
    "V3GetActivityResponseItemItemAnnotationFocusPosition",
    "V3GetActivityResponseItemItemAnnotationHighlightRect",
    "V3GetActivityResponseItemItemAnnotationHighlightRectRect",
    "V3GetActivityResponseItemItemAuthor",
    "V3GetActivityResponseItemItemAuthorAvatar",
    "V3GetActivityResponseItemItemEndorsement",
]


class V3GetActivityResponseItemItemAnnotationAnchorPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class V3GetActivityResponseItemItemAnnotationFocusPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class V3GetActivityResponseItemItemAnnotationHighlightRectRect(BaseModel):
    x1: float

    x2: float

    y1: float

    y2: float


class V3GetActivityResponseItemItemAnnotationHighlightRect(BaseModel):
    page_index: float = FieldInfo(alias="pageIndex")

    rects: List[V3GetActivityResponseItemItemAnnotationHighlightRectRect]


class V3GetActivityResponseItemItemAnnotation(BaseModel):
    anchor_position: V3GetActivityResponseItemItemAnnotationAnchorPosition = FieldInfo(alias="anchorPosition")

    focus_position: V3GetActivityResponseItemItemAnnotationFocusPosition = FieldInfo(alias="focusPosition")

    highlight_rects: List[V3GetActivityResponseItemItemAnnotationHighlightRect] = FieldInfo(alias="highlightRects")

    selected_text: str = FieldInfo(alias="selectedText")

    type: Literal["highlight"]

    color: Optional[str] = None


class V3GetActivityResponseItemItemAuthorAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class V3GetActivityResponseItemItemAuthor(BaseModel):
    id: str

    avatar: Optional[List[V3GetActivityResponseItemItemAuthorAvatar]] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)


class V3GetActivityResponseItemItemEndorsement(BaseModel):
    id: str

    name: str


class V3GetActivityResponseItemItem(BaseModel):
    id: str

    annotation: Optional[V3GetActivityResponseItemItemAnnotation] = None

    author: V3GetActivityResponseItemItemAuthor

    body: Optional[str] = None

    date: str

    endorsements: List[V3GetActivityResponseItemItemEndorsement]

    has_downvoted: bool = FieldInfo(alias="hasDownvoted")

    has_flagged: bool = FieldInfo(alias="hasFlagged")

    has_upvoted: bool = FieldInfo(alias="hasUpvoted")

    is_author: bool = FieldInfo(alias="isAuthor")

    paper_group_id: str = FieldInfo(alias="paperGroupId")

    paper_title: str = FieldInfo(alias="paperTitle")

    paper_version_id: str = FieldInfo(alias="paperVersionId")

    parent_comment_id: Optional[str] = FieldInfo(alias="parentCommentId", default=None)

    tag: str

    title: Optional[str] = None

    universal_id: str = FieldInfo(alias="universalId")

    upvotes: float

    was_edited: bool = FieldInfo(alias="wasEdited")


class V3GetActivityResponseItem(BaseModel):
    date: str

    item: V3GetActivityResponseItemItem

    liked: float

    type: Literal["comment"]

    paper_likes: Optional[float] = FieldInfo(alias="paperLikes", default=None)

    paper_publication_date: Optional[str] = FieldInfo(alias="paperPublicationDate", default=None)

    paper_topics: Optional[List[str]] = FieldInfo(alias="paperTopics", default=None)


V3GetActivityResponse: TypeAlias = List[V3GetActivityResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .v3.v3 import (
    V3Resource,
    AsyncV3Resource,
    V3ResourceWithRawResponse,
    AsyncV3ResourceWithRawResponse,
    V3ResourceWithStreamingResponse,
    AsyncV3ResourceWithStreamingResponse,
)
from ...types import user_get_private_notes_params
from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from .preferences.preferences import (
    PreferencesResource,
    AsyncPreferencesResource,
    PreferencesResourceWithRawResponse,
    AsyncPreferencesResourceWithRawResponse,
    PreferencesResourceWithStreamingResponse,
    AsyncPreferencesResourceWithStreamingResponse,
)
from ...types.user_get_private_notes_response import UserGetPrivateNotesResponse
from ...types.user_weigh_weekly_reputation_response import UserWeighWeeklyReputationResponse

__all__ = ["UsersResource", "AsyncUsersResource"]


class UsersResource(SyncAPIResource):
    @cached_property
    def v3(self) -> V3Resource:
        return V3Resource(self._client)

    @cached_property
    def preferences(self) -> PreferencesResource:
        return PreferencesResource(self._client)

    @cached_property
    def with_raw_response(self) -> UsersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return UsersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> UsersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return UsersResourceWithStreamingResponse(self)

    def get_private_notes(
        self,
        uid: str,
        *,
        limit: str | Omit = omit,
        page: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> UserGetPrivateNotesResponse:
        """
        Get private notes for a user with pagination

        Source file:
        `api-server/src/controllers/v1/users/get-private-notes.controller.ts`

        Args:
          uid: ignored field

          limit: Items per page (default: 10)

          page: Page number (default: 0)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not uid:
            raise ValueError(f"Expected a non-empty value for `uid` but received {uid!r}")
        return self._get(
            f"/v1/users/{uid}/notes",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    user_get_private_notes_params.UserGetPrivateNotesParams,
                ),
            ),
            cast_to=UserGetPrivateNotesResponse,
        )

    def weigh_weekly_reputation(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> UserWeighWeeklyReputationResponse:
        """
        Calculates and updates weekly reputation weights for users

        Source file:
        `api-server/src/controllers/v1/users/weigh-weekly-reputation.controller.ts`
        """
        return self._post(
            "/v1/users/weigh-weekly-reputation",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserWeighWeeklyReputationResponse,
        )


class AsyncUsersResource(AsyncAPIResource):
    @cached_property
    def v3(self) -> AsyncV3Resource:
        return AsyncV3Resource(self._client)

    @cached_property
    def preferences(self) -> AsyncPreferencesResource:
        return AsyncPreferencesResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncUsersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncUsersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncUsersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncUsersResourceWithStreamingResponse(self)

    async def get_private_notes(
        self,
        uid: str,
        *,
        limit: str | Omit = omit,
        page: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> UserGetPrivateNotesResponse:
        """
        Get private notes for a user with pagination

        Source file:
        `api-server/src/controllers/v1/users/get-private-notes.controller.ts`

        Args:
          uid: ignored field

          limit: Items per page (default: 10)

          page: Page number (default: 0)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not uid:
            raise ValueError(f"Expected a non-empty value for `uid` but received {uid!r}")
        return await self._get(
            f"/v1/users/{uid}/notes",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "page": page,
                    },
                    user_get_private_notes_params.UserGetPrivateNotesParams,
                ),
            ),
            cast_to=UserGetPrivateNotesResponse,
        )

    async def weigh_weekly_reputation(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> UserWeighWeeklyReputationResponse:
        """
        Calculates and updates weekly reputation weights for users

        Source file:
        `api-server/src/controllers/v1/users/weigh-weekly-reputation.controller.ts`
        """
        return await self._post(
            "/v1/users/weigh-weekly-reputation",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=UserWeighWeeklyReputationResponse,
        )


class UsersResourceWithRawResponse:
    def __init__(self, users: UsersResource) -> None:
        self._users = users

        self.get_private_notes = to_raw_response_wrapper(
            users.get_private_notes,
        )
        self.weigh_weekly_reputation = to_raw_response_wrapper(
            users.weigh_weekly_reputation,
        )

    @cached_property
    def v3(self) -> V3ResourceWithRawResponse:
        return V3ResourceWithRawResponse(self._users.v3)

    @cached_property
    def preferences(self) -> PreferencesResourceWithRawResponse:
        return PreferencesResourceWithRawResponse(self._users.preferences)


class AsyncUsersResourceWithRawResponse:
    def __init__(self, users: AsyncUsersResource) -> None:
        self._users = users

        self.get_private_notes = async_to_raw_response_wrapper(
            users.get_private_notes,
        )
        self.weigh_weekly_reputation = async_to_raw_response_wrapper(
            users.weigh_weekly_reputation,
        )

    @cached_property
    def v3(self) -> AsyncV3ResourceWithRawResponse:
        return AsyncV3ResourceWithRawResponse(self._users.v3)

    @cached_property
    def preferences(self) -> AsyncPreferencesResourceWithRawResponse:
        return AsyncPreferencesResourceWithRawResponse(self._users.preferences)


class UsersResourceWithStreamingResponse:
    def __init__(self, users: UsersResource) -> None:
        self._users = users

        self.get_private_notes = to_streamed_response_wrapper(
            users.get_private_notes,
        )
        self.weigh_weekly_reputation = to_streamed_response_wrapper(
            users.weigh_weekly_reputation,
        )

    @cached_property
    def v3(self) -> V3ResourceWithStreamingResponse:
        return V3ResourceWithStreamingResponse(self._users.v3)

    @cached_property
    def preferences(self) -> PreferencesResourceWithStreamingResponse:
        return PreferencesResourceWithStreamingResponse(self._users.preferences)


class AsyncUsersResourceWithStreamingResponse:
    def __init__(self, users: AsyncUsersResource) -> None:
        self._users = users

        self.get_private_notes = async_to_streamed_response_wrapper(
            users.get_private_notes,
        )
        self.weigh_weekly_reputation = async_to_streamed_response_wrapper(
            users.weigh_weekly_reputation,
        )

    @cached_property
    def v3(self) -> AsyncV3ResourceWithStreamingResponse:
        return AsyncV3ResourceWithStreamingResponse(self._users.v3)

    @cached_property
    def preferences(self) -> AsyncPreferencesResourceWithStreamingResponse:
        return AsyncPreferencesResourceWithStreamingResponse(self._users.preferences)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, Optional, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.users import (
    V3SearchResponse,
    V3GetActivityResponse,
    V3GetFollowersResponse,
    V3UploadAvatarResponse,
    V3GetUserByUuidResponse,
    V3UpdateProfileResponse,
    V3GetCurrentUserResponse,
    V3GetLeaderboardResponse,
    V3GetClaimedPapersResponse,
    V3GetViewedHistoryResponse,
    V3ToggleFollowUserResponse,
    V3UpdatePreferencesResponse,
    V3AutocompleteProfileResponse,
    V3GetFeaturedActivityResponse,
    V3ProcessNotificationEmailResponse,
)

# pyright: reportDeprecated=false

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV3:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_autocomplete_profile(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = client.users.v3.autocomplete_profile(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(V3AutocompleteProfileResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_autocomplete_profile(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.users.v3.with_raw_response.autocomplete_profile(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3AutocompleteProfileResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_autocomplete_profile(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.users.v3.with_streaming_response.autocomplete_profile(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = response.parse()
                assert_matches_type(V3AutocompleteProfileResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete_banner(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.delete_banner(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete_banner(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.delete_banner(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete_banner(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.delete_banner(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_delete_banner(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `banner_id` but received ''"):
            client.users.v3.with_raw_response.delete_banner(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete_own_user(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.delete_own_user()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete_own_user(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.delete_own_user()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete_own_user(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.delete_own_user() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_activity(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.get_activity(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3GetActivityResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_activity_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.get_activity(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            sort="date",
        )
        assert_matches_type(V3GetActivityResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_activity(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.get_activity(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3GetActivityResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_activity(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.get_activity(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3GetActivityResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_get_activity(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.users.v3.with_raw_response.get_activity(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_claimed_papers(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.get_claimed_papers(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3GetClaimedPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_claimed_papers_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.get_claimed_papers(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            sort="date",
        )
        assert_matches_type(V3GetClaimedPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_claimed_papers(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.get_claimed_papers(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3GetClaimedPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_claimed_papers(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.get_claimed_papers(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3GetClaimedPapersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_get_claimed_papers(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.users.v3.with_raw_response.get_claimed_papers(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_current_user(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.get_current_user()
        assert_matches_type(V3GetCurrentUserResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_current_user(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.get_current_user()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3GetCurrentUserResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_current_user(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.get_current_user() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3GetCurrentUserResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_featured_activity(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.get_featured_activity(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3GetFeaturedActivityResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_featured_activity(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.get_featured_activity(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3GetFeaturedActivityResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_featured_activity(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.get_featured_activity(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3GetFeaturedActivityResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_get_featured_activity(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.users.v3.with_raw_response.get_featured_activity(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_followers(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.get_followers(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3GetFollowersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_followers(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.get_followers(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3GetFollowersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_followers(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.get_followers(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3GetFollowersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_get_followers(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.users.v3.with_raw_response.get_followers(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_leaderboard(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.get_leaderboard()
        assert_matches_type(V3GetLeaderboardResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_leaderboard(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.get_leaderboard()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3GetLeaderboardResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_leaderboard(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.get_leaderboard() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3GetLeaderboardResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_user_by_uuid(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.get_user_by_uuid(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3GetUserByUuidResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_user_by_uuid(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.get_user_by_uuid(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3GetUserByUuidResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_user_by_uuid(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.get_user_by_uuid(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3GetUserByUuidResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_get_user_by_uuid(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.users.v3.with_raw_response.get_user_by_uuid(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_viewed_history(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.get_viewed_history()
        assert_matches_type(V3GetViewedHistoryResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_viewed_history_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.get_viewed_history(
            offset="offset",
            search="search",
        )
        assert_matches_type(V3GetViewedHistoryResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_viewed_history(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.get_viewed_history()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3GetViewedHistoryResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_viewed_history(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.get_viewed_history() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3GetViewedHistoryResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_notification_email(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = client.users.v3.process_notification_email(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(V3ProcessNotificationEmailResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_process_notification_email(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.users.v3.with_raw_response.process_notification_email(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3ProcessNotificationEmailResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_process_notification_email(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.users.v3.with_streaming_response.process_notification_email(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = response.parse()
                assert_matches_type(V3ProcessNotificationEmailResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_process_notification_email(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
                client.users.v3.with_raw_response.process_notification_email(
                    "",
                )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_search(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.search(
            q="x",
        )
        assert_matches_type(V3SearchResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_search_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.search(
            q="x",
            limit="limit",
        )
        assert_matches_type(V3SearchResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_search(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.search(
            q="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3SearchResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_search(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.search(
            q="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3SearchResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_toggle_follow_user(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.toggle_follow_user(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3ToggleFollowUserResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_toggle_follow_user(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.toggle_follow_user(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3ToggleFollowUserResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_toggle_follow_user(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.toggle_follow_user(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3ToggleFollowUserResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_toggle_follow_user(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.users.v3.with_raw_response.toggle_follow_user(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_preferences(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.update_preferences()
        assert_matches_type(V3UpdatePreferencesResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_preferences_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.update_preferences(
            banners=[
                {
                    "link": "link",
                    "name": "name",
                    "type": "success",
                }
            ],
            base={
                "assistant_custom_styles": [
                    {
                        "id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                        "instructions": "x",
                        "name": "x",
                    }
                ],
                "assistant_style_selection": "default",
                "default_private_paper_sidebar_tab": "assistant",
                "default_public_paper_sidebar_tab": "comments",
                "feed_sort": "Hot",
                "is_dark_mode_enabled": True,
                "is_debug_mode_enabled": True,
                "is_members_sidebar_visible": True,
                "preferred_language": "am",
                "preferred_llm_model": "preferredLlmModel",
                "reading_mode_enabled": True,
                "show_model_thinking": True,
                "tooling_pane_width": 0,
                "web_search": "off",
            },
        )
        assert_matches_type(V3UpdatePreferencesResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update_preferences(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.update_preferences()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3UpdatePreferencesResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update_preferences(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.update_preferences() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3UpdatePreferencesResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_profile(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.update_profile()
        assert_matches_type(V3UpdateProfileResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_profile_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.update_profile(
            biography="biography",
            bluesky_username="blueskyUsername",
            github_username="githubUsername",
            institution="institution",
            linkedin_username="linkedinUsername",
            location="location",
            public_email="dev@stainless.com",
            real_name="x",
            username="username",
            x_username="xUsername",
        )
        assert_matches_type(V3UpdateProfileResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update_profile(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.update_profile()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3UpdateProfileResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update_profile(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.update_profile() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3UpdateProfileResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_upload_avatar(self, client: AlphaxivCat) -> None:
        v3 = client.users.v3.upload_avatar()
        assert_matches_type(Optional[V3UploadAvatarResponse], v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_upload_avatar(self, client: AlphaxivCat) -> None:
        response = client.users.v3.with_raw_response.upload_avatar()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(Optional[V3UploadAvatarResponse], v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_upload_avatar(self, client: AlphaxivCat) -> None:
        with client.users.v3.with_streaming_response.upload_avatar() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(Optional[V3UploadAvatarResponse], v3, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncV3:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_autocomplete_profile(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = await async_client.users.v3.autocomplete_profile(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(V3AutocompleteProfileResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_autocomplete_profile(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.users.v3.with_raw_response.autocomplete_profile(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3AutocompleteProfileResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_autocomplete_profile(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.users.v3.with_streaming_response.autocomplete_profile(
                user_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = await response.parse()
                assert_matches_type(V3AutocompleteProfileResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete_banner(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.delete_banner(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete_banner(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.delete_banner(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete_banner(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.delete_banner(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_delete_banner(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `banner_id` but received ''"):
            await async_client.users.v3.with_raw_response.delete_banner(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete_own_user(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.delete_own_user()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete_own_user(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.delete_own_user()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete_own_user(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.delete_own_user() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_activity(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.get_activity(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3GetActivityResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_activity_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.get_activity(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            sort="date",
        )
        assert_matches_type(V3GetActivityResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_activity(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.get_activity(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3GetActivityResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_activity(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.get_activity(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3GetActivityResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_get_activity(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.users.v3.with_raw_response.get_activity(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_claimed_papers(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.get_claimed_papers(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3GetClaimedPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_claimed_papers_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.get_claimed_papers(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            sort="date",
        )
        assert_matches_type(V3GetClaimedPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_claimed_papers(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.get_claimed_papers(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3GetClaimedPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_claimed_papers(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.get_claimed_papers(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3GetClaimedPapersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_get_claimed_papers(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.users.v3.with_raw_response.get_claimed_papers(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_current_user(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.get_current_user()
        assert_matches_type(V3GetCurrentUserResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_current_user(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.get_current_user()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3GetCurrentUserResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_current_user(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.get_current_user() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3GetCurrentUserResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_featured_activity(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.get_featured_activity(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3GetFeaturedActivityResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_featured_activity(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.get_featured_activity(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3GetFeaturedActivityResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_featured_activity(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.get_featured_activity(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3GetFeaturedActivityResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_get_featured_activity(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.users.v3.with_raw_response.get_featured_activity(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_followers(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.get_followers(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3GetFollowersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_followers(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.get_followers(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3GetFollowersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_followers(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.get_followers(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3GetFollowersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_get_followers(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.users.v3.with_raw_response.get_followers(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_leaderboard(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.get_leaderboard()
        assert_matches_type(V3GetLeaderboardResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_leaderboard(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.get_leaderboard()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3GetLeaderboardResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_leaderboard(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.get_leaderboard() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3GetLeaderboardResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_user_by_uuid(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.get_user_by_uuid(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3GetUserByUuidResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_user_by_uuid(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.get_user_by_uuid(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3GetUserByUuidResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_user_by_uuid(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.get_user_by_uuid(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3GetUserByUuidResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_get_user_by_uuid(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.users.v3.with_raw_response.get_user_by_uuid(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_viewed_history(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.get_viewed_history()
        assert_matches_type(V3GetViewedHistoryResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_viewed_history_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.get_viewed_history(
            offset="offset",
            search="search",
        )
        assert_matches_type(V3GetViewedHistoryResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_viewed_history(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.get_viewed_history()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3GetViewedHistoryResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_viewed_history(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.get_viewed_history() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3GetViewedHistoryResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_notification_email(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = await async_client.users.v3.process_notification_email(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert_matches_type(V3ProcessNotificationEmailResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_process_notification_email(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.users.v3.with_raw_response.process_notification_email(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3ProcessNotificationEmailResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_process_notification_email(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.users.v3.with_streaming_response.process_notification_email(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = await response.parse()
                assert_matches_type(V3ProcessNotificationEmailResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_process_notification_email(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
                await async_client.users.v3.with_raw_response.process_notification_email(
                    "",
                )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_search(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.search(
            q="x",
        )
        assert_matches_type(V3SearchResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_search_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.search(
            q="x",
            limit="limit",
        )
        assert_matches_type(V3SearchResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_search(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.search(
            q="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3SearchResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_search(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.search(
            q="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3SearchResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_toggle_follow_user(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.toggle_follow_user(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3ToggleFollowUserResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_toggle_follow_user(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.toggle_follow_user(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3ToggleFollowUserResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_toggle_follow_user(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.toggle_follow_user(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3ToggleFollowUserResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_toggle_follow_user(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.users.v3.with_raw_response.toggle_follow_user(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_preferences(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.update_preferences()
        assert_matches_type(V3UpdatePreferencesResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_preferences_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.update_preferences(
            banners=[
                {
                    "link": "link",
                    "name": "name",
                    "type": "success",
                }
            ],
            base={
                "assistant_custom_styles": [
                    {
                        "id": "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                        "instructions": "x",
                        "name": "x",
                    }
                ],
                "assistant_style_selection": "default",
                "default_private_paper_sidebar_tab": "assistant",
                "default_public_paper_sidebar_tab": "comments",
                "feed_sort": "Hot",
                "is_dark_mode_enabled": True,
                "is_debug_mode_enabled": True,
                "is_members_sidebar_visible": True,
                "preferred_language": "am",
                "preferred_llm_model": "preferredLlmModel",
                "reading_mode_enabled": True,
                "show_model_thinking": True,
                "tooling_pane_width": 0,
                "web_search": "off",
            },
        )
        assert_matches_type(V3UpdatePreferencesResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update_preferences(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.update_preferences()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3UpdatePreferencesResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update_preferences(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.update_preferences() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3UpdatePreferencesResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_profile(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.update_profile()
        assert_matches_type(V3UpdateProfileResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_profile_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.update_profile(
            biography="biography",
            bluesky_username="blueskyUsername",
            github_username="githubUsername",
            institution="institution",
            linkedin_username="linkedinUsername",
            location="location",
            public_email="dev@stainless.com",
            real_name="x",
            username="username",
            x_username="xUsername",
        )
        assert_matches_type(V3UpdateProfileResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update_profile(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.update_profile()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3UpdateProfileResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update_profile(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.update_profile() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3UpdateProfileResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_upload_avatar(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.users.v3.upload_avatar()
        assert_matches_type(Optional[V3UploadAvatarResponse], v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_upload_avatar(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.users.v3.with_raw_response.upload_avatar()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(Optional[V3UploadAvatarResponse], v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_upload_avatar(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.users.v3.with_streaming_response.upload_avatar() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(Optional[V3UploadAvatarResponse], v3, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["PaperEmailAuthorResponse"]


class PaperEmailAuthorResponse(BaseModel):
    status: float



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ...._utils import PropertyInfo

__all__ = ["ModeratorToggleFlagsParams"]


class ModeratorToggleFlagsParams(TypedDict, total=False):
    addressed: bool

    closed: bool

    flag_addressed: Annotated[bool, PropertyInfo(alias="flagAddressed")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V1GetModeratorFeedParams"]


class V1GetModeratorFeedParams(TypedDict, total=False):
    feed_type: Annotated[Literal["all", "flagged", "recent"], PropertyInfo(alias="feedType")]

    page: str

    page_size: Annotated[str, PropertyInfo(alias="pageSize")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["V3RetrieveDiversePapersParams"]


class V3RetrieveDiversePapersParams(TypedDict, total=False):
    topics: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.papers import (
    KickoffDailyGitHubStarUpdateResponse,
    KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestKickoffDailyGitHubStars:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update(self, client: AlphaxivCat) -> None:
        kickoff_daily_github_star = client.papers.kickoff_daily_github_stars.update(
            "max",
        )
        assert_matches_type(KickoffDailyGitHubStarUpdateResponse, kickoff_daily_github_star, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: AlphaxivCat) -> None:
        response = client.papers.kickoff_daily_github_stars.with_raw_response.update(
            "max",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        kickoff_daily_github_star = response.parse()
        assert_matches_type(KickoffDailyGitHubStarUpdateResponse, kickoff_daily_github_star, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: AlphaxivCat) -> None:
        with client.papers.kickoff_daily_github_stars.with_streaming_response.update(
            "max",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            kickoff_daily_github_star = response.parse()
            assert_matches_type(KickoffDailyGitHubStarUpdateResponse, kickoff_daily_github_star, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `max` but received ''"):
            client.papers.kickoff_daily_github_stars.with_raw_response.update(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_daily_github_stars(self, client: AlphaxivCat) -> None:
        kickoff_daily_github_star = client.papers.kickoff_daily_github_stars.kickoff_daily_github_stars()
        assert_matches_type(
            KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse, kickoff_daily_github_star, path=["response"]
        )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_daily_github_stars(self, client: AlphaxivCat) -> None:
        response = client.papers.kickoff_daily_github_stars.with_raw_response.kickoff_daily_github_stars()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        kickoff_daily_github_star = response.parse()
        assert_matches_type(
            KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse, kickoff_daily_github_star, path=["response"]
        )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_daily_github_stars(self, client: AlphaxivCat) -> None:
        with client.papers.kickoff_daily_github_stars.with_streaming_response.kickoff_daily_github_stars() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            kickoff_daily_github_star = response.parse()
            assert_matches_type(
                KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse, kickoff_daily_github_star, path=["response"]
            )

        assert cast(Any, response.is_closed) is True


class TestAsyncKickoffDailyGitHubStars:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncAlphaxivCat) -> None:
        kickoff_daily_github_star = await async_client.papers.kickoff_daily_github_stars.update(
            "max",
        )
        assert_matches_type(KickoffDailyGitHubStarUpdateResponse, kickoff_daily_github_star, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.kickoff_daily_github_stars.with_raw_response.update(
            "max",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        kickoff_daily_github_star = await response.parse()
        assert_matches_type(KickoffDailyGitHubStarUpdateResponse, kickoff_daily_github_star, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.kickoff_daily_github_stars.with_streaming_response.update(
            "max",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            kickoff_daily_github_star = await response.parse()
            assert_matches_type(KickoffDailyGitHubStarUpdateResponse, kickoff_daily_github_star, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `max` but received ''"):
            await async_client.papers.kickoff_daily_github_stars.with_raw_response.update(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_daily_github_stars(self, async_client: AsyncAlphaxivCat) -> None:
        kickoff_daily_github_star = await async_client.papers.kickoff_daily_github_stars.kickoff_daily_github_stars()
        assert_matches_type(
            KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse, kickoff_daily_github_star, path=["response"]
        )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_daily_github_stars(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.kickoff_daily_github_stars.with_raw_response.kickoff_daily_github_stars()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        kickoff_daily_github_star = await response.parse()
        assert_matches_type(
            KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse, kickoff_daily_github_star, path=["response"]
        )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_daily_github_stars(self, async_client: AsyncAlphaxivCat) -> None:
        async with (
            async_client.papers.kickoff_daily_github_stars.with_streaming_response.kickoff_daily_github_stars()
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            kickoff_daily_github_star = await response.parse()
            assert_matches_type(
                KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse, kickoff_daily_github_star, path=["response"]
            )

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["XMentionUpdateResponse", "Mention", "MentionQuality"]


class MentionQuality(BaseModel):
    contains_profanity: bool = FieldInfo(alias="containsProfanity")

    has_unique_perspective: bool = FieldInfo(alias="hasUniquePerspective")

    is_bot: bool = FieldInfo(alias="isBot")

    is_english: bool = FieldInfo(alias="isEnglish")

    is_grok: bool = FieldInfo(alias="isGrok")

    is_meaningful: bool = FieldInfo(alias="isMeaningful")

    is_relevant: bool = FieldInfo(alias="isRelevant")

    reason: str

    should_include: bool = FieldInfo(alias="shouldInclude")


class Mention(BaseModel):
    author_avatar: str = FieldInfo(alias="authorAvatar")

    author_name: str = FieldInfo(alias="authorName")

    author_username: str = FieldInfo(alias="authorUsername")

    conversation_id: str = FieldInfo(alias="conversationId")

    created_at: str = FieldInfo(alias="createdAt")

    likes: float

    quality: MentionQuality

    replies: float

    retweets: float

    text: str

    tweet_id: str = FieldInfo(alias="tweetId")

    tweet_url: str = FieldInfo(alias="tweetUrl")


class XMentionUpdateResponse(BaseModel):
    mentions: List[Mention]

    quality_tweets_count: float = FieldInfo(alias="qualityTweetsCount")

    total_tweets_found: float = FieldInfo(alias="totalTweetsFound")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["MessageSetFeedbackParams", "Feedback"]


class MessageSetFeedbackParams(TypedDict, total=False):
    feedback: Required[Optional[Feedback]]


class Feedback(TypedDict, total=False):
    type: Required[Literal["upvote", "downvote"]]

    category: Optional[str]

    details: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from .archive import (
    ArchiveResource,
    AsyncArchiveResource,
    ArchiveResourceWithRawResponse,
    AsyncArchiveResourceWithRawResponse,
    ArchiveResourceWithStreamingResponse,
    AsyncArchiveResourceWithStreamingResponse,
)
from ...._types import Body, Query, Headers, NoneType, NotGiven, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.notifications import v4_subscribe_params, v4_unsubscribe_params
from ....types.notifications.v4_list_notifications_response import V4ListNotificationsResponse

__all__ = ["V4Resource", "AsyncV4Resource"]


class V4Resource(SyncAPIResource):
    @cached_property
    def archive(self) -> ArchiveResource:
        return ArchiveResource(self._client)

    @cached_property
    def with_raw_response(self) -> V4ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V4ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V4ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V4ResourceWithStreamingResponse(self)

    def list_notifications(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V4ListNotificationsResponse:
        """
        Returns all active notifications.

        Source file:
        `api-server/src/controllers/notifications/v4/get-notifications.controller.ts`
        """
        return self._get(
            "/notifications/v4",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V4ListNotificationsResponse,
        )

    def subscribe(
        self,
        *,
        subscription: v4_subscribe_params.Subscription,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Subscribes the current user to push notifications

        Source file:
        `api-server/src/controllers/notifications/v4/subscribe.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/notifications/v4/subscribe",
            body=maybe_transform({"subscription": subscription}, v4_subscribe_params.V4SubscribeParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def unsubscribe(
        self,
        *,
        endpoint: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Unsubscribes the current user to push notifications

        Source file:
        `api-server/src/controllers/notifications/v4/unsubscribe.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/notifications/v4/unsubscribe",
            body=maybe_transform({"endpoint": endpoint}, v4_unsubscribe_params.V4UnsubscribeParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncV4Resource(AsyncAPIResource):
    @cached_property
    def archive(self) -> AsyncArchiveResource:
        return AsyncArchiveResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncV4ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV4ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV4ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV4ResourceWithStreamingResponse(self)

    async def list_notifications(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V4ListNotificationsResponse:
        """
        Returns all active notifications.

        Source file:
        `api-server/src/controllers/notifications/v4/get-notifications.controller.ts`
        """
        return await self._get(
            "/notifications/v4",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V4ListNotificationsResponse,
        )

    async def subscribe(
        self,
        *,
        subscription: v4_subscribe_params.Subscription,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Subscribes the current user to push notifications

        Source file:
        `api-server/src/controllers/notifications/v4/subscribe.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/notifications/v4/subscribe",
            body=await async_maybe_transform({"subscription": subscription}, v4_subscribe_params.V4SubscribeParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def unsubscribe(
        self,
        *,
        endpoint: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Unsubscribes the current user to push notifications

        Source file:
        `api-server/src/controllers/notifications/v4/unsubscribe.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/notifications/v4/unsubscribe",
            body=await async_maybe_transform({"endpoint": endpoint}, v4_unsubscribe_params.V4UnsubscribeParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class V4ResourceWithRawResponse:
    def __init__(self, v4: V4Resource) -> None:
        self._v4 = v4

        self.list_notifications = to_raw_response_wrapper(
            v4.list_notifications,
        )
        self.subscribe = to_raw_response_wrapper(
            v4.subscribe,
        )
        self.unsubscribe = to_raw_response_wrapper(
            v4.unsubscribe,
        )

    @cached_property
    def archive(self) -> ArchiveResourceWithRawResponse:
        return ArchiveResourceWithRawResponse(self._v4.archive)


class AsyncV4ResourceWithRawResponse:
    def __init__(self, v4: AsyncV4Resource) -> None:
        self._v4 = v4

        self.list_notifications = async_to_raw_response_wrapper(
            v4.list_notifications,
        )
        self.subscribe = async_to_raw_response_wrapper(
            v4.subscribe,
        )
        self.unsubscribe = async_to_raw_response_wrapper(
            v4.unsubscribe,
        )

    @cached_property
    def archive(self) -> AsyncArchiveResourceWithRawResponse:
        return AsyncArchiveResourceWithRawResponse(self._v4.archive)


class V4ResourceWithStreamingResponse:
    def __init__(self, v4: V4Resource) -> None:
        self._v4 = v4

        self.list_notifications = to_streamed_response_wrapper(
            v4.list_notifications,
        )
        self.subscribe = to_streamed_response_wrapper(
            v4.subscribe,
        )
        self.unsubscribe = to_streamed_response_wrapper(
            v4.unsubscribe,
        )

    @cached_property
    def archive(self) -> ArchiveResourceWithStreamingResponse:
        return ArchiveResourceWithStreamingResponse(self._v4.archive)


class AsyncV4ResourceWithStreamingResponse:
    def __init__(self, v4: AsyncV4Resource) -> None:
        self._v4 = v4

        self.list_notifications = async_to_streamed_response_wrapper(
            v4.list_notifications,
        )
        self.subscribe = async_to_streamed_response_wrapper(
            v4.subscribe,
        )
        self.unsubscribe = async_to_streamed_response_wrapper(
            v4.unsubscribe,
        )

    @cached_property
    def archive(self) -> AsyncArchiveResourceWithStreamingResponse:
        return AsyncArchiveResourceWithStreamingResponse(self._v4.archive)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V3RequestImplementationParams"]


class V3RequestImplementationParams(TypedDict, total=False):
    paper_title: Required[Annotated[str, PropertyInfo(alias="paperTitle")]]

    universal_paper_id: Required[Annotated[str, PropertyInfo(alias="universalPaperId")]]

    additional_info: Annotated[str, PropertyInfo(alias="additionalInfo")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V1GetWeeklyMessageCountsByUserResponse", "V1GetWeeklyMessageCountsByUserResponseItem"]


class V1GetWeeklyMessageCountsByUserResponseItem(BaseModel):
    count: float

    email: str

    user_id: str = FieldInfo(alias="userId")

    username: str


V1GetWeeklyMessageCountsByUserResponse: TypeAlias = List[V1GetWeeklyMessageCountsByUserResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from .._types import SequenceNotStr

__all__ = ["EmailCaptureResendBouncedEmailParams", "Data"]


class EmailCaptureResendBouncedEmailParams(TypedDict, total=False):
    data: Required[Data]
    """Event data containing bounced emails"""

    type: Required[str]
    """Event type from Resend"""


class Data(TypedDict, total=False):
    """Event data containing bounced emails"""

    to: SequenceNotStr[str]
    """Bounced email addresses"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..._models import BaseModel

__all__ = ["V3ProcessNotificationEmailResponse"]


class V3ProcessNotificationEmailResponse(BaseModel):
    message: str

    success: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V1ResyncResponse"]


class V1ResyncResponse(BaseModel):
    claimed_papers: float = FieldInfo(alias="claimedPapers")
    """How many papers have been claimed since the current sync started"""

    email_domain: str = FieldInfo(alias="emailDomain")

    errored_papers: float = FieldInfo(alias="erroredPapers")
    """How many papers had an error during processing"""

    google_scholar_id: str = FieldInfo(alias="googleScholarId")

    not_found_papers: float = FieldInfo(alias="notFoundPapers")
    """How many papers were not found on arXiv"""

    pending_papers: float = FieldInfo(alias="pendingPapers")
    """
    How many papers are ready and will be claimed once the user verifies their email
    """

    remaining_papers: float = FieldInfo(alias="remainingPapers")
    """How many papers have not been processed at all"""

    sync_started_at_date: str = FieldInfo(alias="syncStartedAtDate")

    verified: bool

    email_local_part: Optional[str] = FieldInfo(alias="emailLocalPart", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable, Optional
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V2ChatParams", "File"]


class V2ChatParams(TypedDict, total=False):
    files: Required[Iterable[File]]

    llm_chat_id: Required[Annotated[Optional[str], PropertyInfo(alias="llmChatId")]]

    message: Required[str]

    paper_version_id: Required[Annotated[Optional[str], PropertyInfo(alias="paperVersionId")]]

    parent_message_id: Required[Annotated[Optional[str], PropertyInfo(alias="parentMessageId")]]

    selection_page_range: Required[Annotated[Optional[Iterable[int]], PropertyInfo(alias="selectionPageRange")]]

    thinking: Required[bool]

    web_search: Required[Annotated[Literal["off", "full"], PropertyInfo(alias="webSearch")]]

    assistant_variant: Annotated[
        Literal["homepage", "paper", "folder", "landing", "folder-add-papers"], PropertyInfo(alias="assistantVariant")
    ]

    folder_add_papers: Annotated[bool, PropertyInfo(alias="folderAddPapers")]

    folder_id: Annotated[str, PropertyInfo(alias="folderId")]

    model: Literal[
        "gemini-2.5-flash",
        "gemini-2.5-pro",
        "gemini-3-flash",
        "gemini-3-pro",
        "gemini-3.1-pro",
        "claude-4.5-sonnet",
        "claude-4.6-sonnet",
        "grok-4",
        "qwen-3",
        "qwen-3-next",
        "qwen-3.5",
        "gpt-5",
        "gpt-5.2",
        "gpt-5.4",
        "gpt-oss-120b",
        "llama-4-maverick",
        "kimi-k2",
        "kimi-k2.5",
        "glm-5",
        "minimax-m2.5",
        "aurelle-1",
    ]


class File(TypedDict, total=False):
    content_type: Required[Annotated[str, PropertyInfo(alias="contentType")]]

    url: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["PreferenceGetFoldersPreferencesResponse"]


class PreferenceGetFoldersPreferencesResponse(BaseModel):
    data: Optional[object] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .shared_copy_response import SharedCopyResponse as SharedCopyResponse
from .shared_retrieve_response import SharedRetrieveResponse as SharedRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .paper_view_count_kickoff_job_params import PaperViewCountKickoffJobParams as PaperViewCountKickoffJobParams
from .paper_view_count_process_job_params import PaperViewCountProcessJobParams as PaperViewCountProcessJobParams
from .paper_view_count_ingest_event_params import PaperViewCountIngestEventParams as PaperViewCountIngestEventParams
from .paper_view_count_kickoff_job_response import PaperViewCountKickoffJobResponse as PaperViewCountKickoffJobResponse
from .paper_view_count_process_job_response import PaperViewCountProcessJobResponse as PaperViewCountProcessJobResponse
from .paper_view_count_ingest_event_response import (
    PaperViewCountIngestEventResponse as PaperViewCountIngestEventResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V3KickoffPaperFullTextParams"]


class V3KickoffPaperFullTextParams(TypedDict, total=False):
    max_papers: Annotated[float, PropertyInfo(alias="maxPapers")]
    """Maximum number of paper versions to process"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v2 import (
    V2Resource,
    AsyncV2Resource,
    V2ResourceWithRawResponse,
    AsyncV2ResourceWithRawResponse,
    V2ResourceWithStreamingResponse,
    AsyncV2ResourceWithStreamingResponse,
)
from .comments import (
    CommentsResource,
    AsyncCommentsResource,
    CommentsResourceWithRawResponse,
    AsyncCommentsResourceWithRawResponse,
    CommentsResourceWithStreamingResponse,
    AsyncCommentsResourceWithStreamingResponse,
)

__all__ = [
    "V2Resource",
    "AsyncV2Resource",
    "V2ResourceWithRawResponse",
    "AsyncV2ResourceWithRawResponse",
    "V2ResourceWithStreamingResponse",
    "AsyncV2ResourceWithStreamingResponse",
    "CommentsResource",
    "AsyncCommentsResource",
    "CommentsResourceWithRawResponse",
    "AsyncCommentsResourceWithRawResponse",
    "CommentsResourceWithStreamingResponse",
    "AsyncCommentsResourceWithStreamingResponse",
]
